@@ -1,7 +1,7 @@
 package Image::TextMode::Canvas;
 
-use Moose;
-
+use Moo;
+use Types::Standard qw( Int ArrayRef );
 use Image::TextMode::Pixel;
 
 =head1 NAME
@@ -27,11 +27,11 @@ of pixels.
 
 =cut
 
-has 'width' => ( is => 'rw', isa => 'Int', default => sub { 0 } );
+has 'width' => ( is => 'rw', lazy => 1, isa => Int, default => 0 );
 
-has 'height' => ( is => 'rw', isa => 'Int', default => sub { 0 } );
+has 'height' => ( is => 'rw', lazy => 1, isa => Int, default => 0 );
 
-has 'pixeldata' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
+has 'pixeldata' => ( is => 'rw', lazy => 1, isa => ArrayRef, default => sub { [] } );
 
 =head1 METHODS
 
@@ -231,17 +231,13 @@ sub ansiscale {
     return $new;
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 AUTHOR
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
