@@ -1,6 +1,6 @@
 package Image::TextMode::Font::8x8;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Font';
 
@@ -270,10 +270,6 @@ has '+chars' => (
     }
 );
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Font::8x8 - 8 x 8 text mode font
@@ -288,7 +284,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
