@@ -1,6 +1,6 @@
 package Image::TextMode::Font::Amiga;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Font';
 
@@ -782,10 +782,6 @@ has '+chars' => (
     }
 );
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Font::Amiga - Amiga-style text mode font
@@ -800,7 +796,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
