@@ -1,18 +1,15 @@
 package Image::TextMode::Format::ADF;
 
-use Moose;
+use Moo;
+use Types::Standard qw( HashRef );
 
 extends 'Image::TextMode::Format', 'Image::TextMode::Canvas';
 
 has 'header' =>
-    ( is => 'rw', isa => 'HashRef', default => sub { { version => 1 } } );
+    ( is => 'rw', isa => HashRef, default => sub { { version => 1 } } );
 
 sub extensions { return 'adf' }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Format::ADF - read and write ADF files
@@ -57,7 +54,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
