@@ -1,6 +1,6 @@
 package Image::TextMode::Format::ANSI;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Format', 'Image::TextMode::Canvas';
 
@@ -12,10 +12,6 @@ has '+render_options' => ( default => sub { { blink_mode => 1 } } );
 
 sub extensions { return 'ans', 'cia', 'ice' }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Format::ANSI - read and write ANSI files
@@ -41,7 +37,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
