@@ -1,6 +1,6 @@
 package Image::TextMode::Format::ANSIMation;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Format', 'Image::TextMode::Animation';
 
@@ -10,10 +10,6 @@ has '+palette' => ( default => sub { Image::TextMode::Palette::ANSI->new } );
 
 sub extensions { return }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Format::ANSIMation - read and write ANSIMation files
@@ -41,7 +37,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
