@@ -1,22 +1,19 @@
 package Image::TextMode::Format::IDF;
 
-use Moose;
+use Moo;
+use Types::Standard qw( HashRef );
 
 extends 'Image::TextMode::Format', 'Image::TextMode::Canvas';
 
 has 'header' => (
     is  => 'rw',
-    isa => 'HashRef',
+    isa => HashRef,
     default =>
         sub { { id => '\x{04}1.4', x0 => 0, y0 => 0, x1 => 0, y1 => 0 } }
 );
 
 sub extensions { return 'idf' }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Format::IDF - read and write IDF files
@@ -49,7 +46,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
