@@ -1,6 +1,7 @@
 package Image::TextMode::Format::XBin;
 
-use Moose;
+use Moo;
+use Types::Standard qw( HashRef );
 
 # Flag byte constants
 my $FLAG_PALETTE          = 1;
@@ -13,7 +14,7 @@ extends 'Image::TextMode::Format', 'Image::TextMode::Canvas';
 
 has 'header' => (
     is      => 'rw',
-    isa     => 'HashRef',
+    isa     => HashRef,
     default => sub {
         {   id      => 'XBIN',
             eofchar => chr( 26 ),
@@ -44,10 +45,6 @@ sub has_fivetwelve_chars {
 
 sub extensions { return 'xb', 'xbin' }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Format::XBin - read and write XBin files
@@ -129,7 +126,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
