@@ -1,12 +1,8 @@
 package Image::TextMode::Palette;
 
-use Moose;
-
-has 'colors' => ( is => 'rw', isa => 'ArrayRef', default => sub { [] } );
-
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
+use Moo;
+use Types::Standard qw( ArrayRef );
+has 'colors' => ( is => 'rw', isa => ArrayRef, default => sub { [] } );
 
 =head1 NAME
 
@@ -36,7 +32,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
