@@ -1,6 +1,6 @@
 package Image::TextMode::Palette::Atari;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Palette';
 
@@ -12,10 +12,6 @@ has '+colors' => (
     }
 );
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Palette::Atari - 2-color Atari palette
@@ -30,7 +26,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
