@@ -1,6 +1,6 @@
 package Image::TextMode::Reader;
 
-use Moose;
+use Moo;
 
 use Carp 'croak';
 
@@ -63,17 +63,13 @@ sub _get_fh {
     return $fh;
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 AUTHOR
 
 Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
