@@ -1,6 +1,6 @@
 package Image::TextMode::Reader::ADF;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Reader';
 
@@ -74,10 +74,6 @@ sub _parse_font {
     );
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Reader::ADF - Reads ADF files
@@ -92,7 +88,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
