@@ -1,6 +1,7 @@
 package Image::TextMode::Reader::ANSI;
 
-use Moose;
+use Moo;
+use Types::Standard qw( Int HashRef Bool Object );
 use charnames ':full';
 
 extends 'Image::TextMode::Reader';
@@ -11,27 +12,27 @@ my $S_CHK_B    = 1;
 my $S_WAIT_LTR = 2;
 my $S_END      = 3;
 
-has 'tabstop' => ( is => 'rw', isa => 'Int', default => sub { 8 } );
+has 'tabstop' => ( is => 'rw', isa => Int, default => 8 );
 
-has 'save_x' => ( is => 'rw', isa => 'Int', default => sub { 0 } );
+has 'save_x' => ( is => 'rw', isa => Int, default => 0 );
 
-has 'save_y' => ( is => 'rw', isa => 'Int', default => sub { 0 } );
+has 'save_y' => ( is => 'rw', isa => Int, default => 0 );
 
-has 'x' => ( is => 'rw', isa => 'Int', default => sub { 0 } );
+has 'x' => ( is => 'rw', isa => Int, default => 0 );
 
-has 'y' => ( is => 'rw', isa => 'Int', default => sub { 0 } );
+has 'y' => ( is => 'rw', isa => Int, default => 0 );
 
-has 'attr' => ( is => 'rw', isa => 'Int', default => sub { 7 } );
+has 'attr' => ( is => 'rw', isa => Int, default => 7 );
 
-has 'rgbattr' => ( is => 'rw', isa => 'HashRef', default => sub { { fg => [ 0xaa, 0xaa, 0xaa ], bg => [ 0, 0, 0 ] } } );
+has 'rgbattr' => ( is => 'rw', isa => HashRef, default => sub { { fg => [ 0xaa, 0xaa, 0xaa ], bg => [ 0, 0, 0 ] } } );
 
-has 'is_truecolor' => ( is => 'rw', isa => 'Bool', default => sub { 0 } );
+has 'is_truecolor' => ( is => 'rw', isa => Bool, default => 0 );
 
-has 'state' => ( is => 'rw', isa => 'Int', default => sub { $S_TXT } );
+has 'state' => ( is => 'rw', isa => Int, default => $S_TXT );
 
-has 'image' => ( is => 'rw', isa => 'Object' );
+has 'image' => ( is => 'rw', isa => Object );
 
-has 'linewrap' => ( is => 'rw', isa => 'Int', default => sub { 80 } );
+has 'linewrap' => ( is => 'rw', isa => Int, default => 80 );
 
 sub _read {
     my ( $self, $image, $fh, $options ) = @_;
@@ -384,10 +385,6 @@ sub store {
     }
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Reader::ANSI - Reads ANSI files
@@ -493,7 +490,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
