@@ -1,6 +1,6 @@
 package Image::TextMode::Reader::ANSIMation;
 
-use Moose;
+use Moo;
 use Image::TextMode::Canvas;
 
 extends 'Image::TextMode::Reader::ANSI';
@@ -30,10 +30,6 @@ sub next_frame {
     $animation->add_frame( Image::TextMode::Canvas->new );
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Reader::ANSIMation - Reads ANSI Animation files
@@ -61,7 +57,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
