@@ -1,6 +1,6 @@
 package Image::TextMode::Reader::Bin;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Reader';
 
@@ -31,10 +31,6 @@ sub _read {
     return $image;
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Reader::Bin - Reads Bin files
@@ -49,7 +45,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
