@@ -1,6 +1,6 @@
 package Image::TextMode::Reader::Tundra;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Reader';
 
@@ -93,10 +93,6 @@ sub _read {
     return $image;
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Reader::Tundra - Reads Tundra files
@@ -111,7 +107,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
