@@ -1,6 +1,6 @@
 package Image::TextMode::Reader::XBin;
 
-use Moose;
+use Moo;
 use Carp 'croak';
 
 extends 'Image::TextMode::Reader';
@@ -186,10 +186,6 @@ sub _parse_uncompressed {
     }
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Reader::XBin - Reads XBin files
@@ -204,7 +200,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
