@@ -1,6 +1,6 @@
 package Image::TextMode::Writer::ADF;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Writer';
 
@@ -54,10 +54,6 @@ sub _pack_pal {
     return pack( 'C*', map { @$_ } @full_pal );
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Writer::ADF - Writes ADF files
@@ -72,7 +68,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
