@@ -1,6 +1,6 @@
 package Image::TextMode::Writer::ANSI;
 
-use Moose;
+use Moo;
 use charnames ':full';
 
 extends 'Image::TextMode::Writer';
@@ -47,10 +47,6 @@ sub _gen_args {
     return join( q{;}, grep { length } ( $bl, $in, $fg, $bg ) );
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Writer::ANSI - Writes ANSI files
@@ -65,7 +61,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
