@@ -1,6 +1,6 @@
 package Image::TextMode::Writer::IDF;
 
-use Moose;
+use Moo;
 use charnames ':full';
 
 extends 'Image::TextMode::Writer';
@@ -33,10 +33,6 @@ sub _write {
     }
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Writer::IDF - Writes IDF files
@@ -52,7 +48,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
