@@ -1,6 +1,6 @@
 package Image::TextMode::Writer::Tundra;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Writer';
 
@@ -33,10 +33,6 @@ sub _assemble_pal {
         | ( $color->[ 2 ] );
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Writer::Tundra - Writes Tundra files
@@ -52,7 +48,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
