@@ -1,6 +1,6 @@
 package Image::TextMode::Writer::XBin;
 
-use Moose;
+use Moo;
 
 extends 'Image::TextMode::Writer';
 
@@ -35,10 +35,6 @@ sub _write {
     }
 }
 
-no Moose;
-
-__PACKAGE__->meta->make_immutable;
-
 =head1 NAME
 
 Image::TextMode::Writer::XBin - Writes XBin files
@@ -54,7 +50,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2013 by Brian Cassidy
+Copyright 2008-2014 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
